@@ -301,6 +301,9 @@ def AttachJVM(jars=None, libs=None):
             args.append('-Djava.library.path=%s' % libs_path)
         jvm_path = getattr(jpype, "getDefaultJVMPath")()
         getattr(jpype, "startJVM")(jvm_path, *args, ignoreUnrecognized=True, convertStrings=True)
+        if "SQLCLI_DEBUG" in os.environ:
+            print("JVM started: class.path=[" + jpype.java.lang.System.getProperty('java.class.path') + "]")
+            print("JVM Version: [" + ".".join([str(x) for x in getattr(jpype, "getJVMVersion")()]) + "]")
 
     if not getattr(jpype, "isThreadAttachedToJVM")():
         getattr(jpype, "attachThreadToJVM")()
@@ -661,7 +664,7 @@ class Cursor(object):
                         warnings.warn("Unknown JDBC convert with constant value " + str(sqltype) +
                                       ":" + self._meta.getColumnClassName(col))
             if "SQLCLI_DEBUG" in os.environ:
-                print("JDBC SQLType=[" + str(converter.__name__) + "] for col [" + str(col) + "]. " +
+                print("[DEBUG] JDBC SQLType=[" + str(converter.__name__) + "] for col [" + str(col) + "]. " +
                       "sqltype=[" + str(sqltype) + ":" + str(m_ColumnClassName) + ":" + m_ColumnTypeName + "]")
             v = converter(self._connection.jconn, self._rs, col, m_ColumnClassName)
             row.append(v)
